pub struct MarketFinancials {
pub expiration_ts: u64,
pub pt_balance: u64,
pub sy_balance: u64,
pub ln_fee_rate_root: f64,
pub last_ln_implied_rate: f64,
pub rate_scalar_root: f64,
}Expand description
Financial parameters for the market
Fields
expiration_ts: u64Expiration timestamp, which is copied from the vault associated with the PT
pt_balance: u64Balance of PT in the market This amount is tracked separately to prevent bugs from token transfers directly to the market
sy_balance: u64Balance of SY in the market This amount is tracked separately to prevent bugs from token transfers directly to the market
ln_fee_rate_root: f64Initial log of fee rate, which decreases over time
last_ln_implied_rate: f64Last seen log of implied rate (APY) for PT Used to maintain continuity of the APY between trades over time
rate_scalar_root: f64Initial rate scalar, which increases over time
Implementations